package svc

import (
	"code.fnuoos.com/go_rely_warehouse/zyos_go_third_party_api.git/db"
	"code.fnuoos.com/go_rely_warehouse/zyos_go_third_party_api.git/db/offical"
	"code.fnuoos.com/go_rely_warehouse/zyos_go_third_party_api.git/kuaishou"
	"code.fnuoos.com/go_rely_warehouse/zyos_go_third_party_api.git/md"
	zhios_third_party_utils "code.fnuoos.com/go_rely_warehouse/zyos_go_third_party_api.git/utils"
	"code.fnuoos.com/go_rely_warehouse/zyos_go_third_party_api.git/zhimeng"
	"encoding/json"
	"github.com/tidwall/gjson"
	"xorm.io/xorm"
)

func KuaiShouKlGoods(eg *xorm.Engine, officialEg *xorm.Engine, dbName string, tikTokArgs map[string]interface{}) *zhimeng.TikTokDetailData {
	arg := map[string]interface{}{
		"cpsLink": tikTokArgs["content"],
	}
	param, kuaishouData := GetKuaishouKey(eg, officialEg, dbName)
	if kuaishouData["authType"] != "2" {
		goods, _ := zhimeng.KuaiShouKlGoods(tikTokArgs)
		return goods
	}
	param["param"] = zhios_third_party_utils.SerializeStr(arg)
	data, err := kuaishou.GetKuishouCpsKlGoods(kuaishouData["sign_secret"], param)
	goods := gjson.Get(data, "data.itemId").String()
	if goods == "" || err != nil {
		return nil
	}
	detail := KuaiShouDetail(eg, officialEg, dbName, map[string]interface{}{"gid": []string{goods}})
	return detail
}

func GetKuaishouKey(eg *xorm.Engine, officialEg *xorm.Engine, dbName string) (map[string]string, map[string]string) {
	kuaishouData := CommKuaishou(eg, officialEg, dbName)
	param := map[string]string{
		"appkey":       kuaishouData["appkey"],
		"access_token": kuaishouData["token"],
	}

	return param, kuaishouData
}
func KuaiShouDetail(eg *xorm.Engine, officialEg *xorm.Engine, dbName string, tikTokArgs map[string]interface{}) *zhimeng.TikTokDetailData {
	arg := map[string]interface{}{
		"itemId": []interface{}{tikTokArgs["gid"]},
	}
	param, kuaishouData := GetKuaishouKey(eg, officialEg, dbName)
	if kuaishouData["authType"] != "2" {
		goods, _ := zhimeng.KuaiShouDetail(tikTokArgs)
		return goods
	}
	param["param"] = zhios_third_party_utils.SerializeStr(arg)
	data, err := kuaishou.GetKuishouCpsGoodsDetail(kuaishouData["sign_secret"], param)
	goods := gjson.Get(data, "data").String()
	if goods == "" || err != nil {
		return nil
	}
	var list = make([]md.KuaishouGoods, 0)
	err = json.Unmarshal([]byte(goods), &list)
	if err != nil {
		return nil
	}
	var detail = zhimeng.TikTokDetailData{}
	for _, v := range list {
		if zhios_third_party_utils.IntToStr(v.GoodsId) == zhios_third_party_utils.AnyToString(tikTokArgs["gid"]) {
			detail = CommGoodsDetail(v)
		}
	}
	return &detail
}
func CommGoodsDetail(goods md.KuaishouGoods) zhimeng.TikTokDetailData {
	var res = zhimeng.TikTokDetailData{
		Commission: zhios_third_party_utils.Float64ToStr(float64(goods.PromotionRate) / 10),
		CostPrice:  zhios_third_party_utils.Float64ToStr(float64(goods.GoodsPrice) / 100),
		GoodsID:    zhios_third_party_utils.IntToStr(goods.GoodsId),
		GoodsImg:   goods.GoodsImageUrl,
		GoodsSales: zhios_third_party_utils.IntToStr(goods.SalesTip),
		GoodsTitle: goods.GoodsTitle,
		Price:      zhios_third_party_utils.Float64ToStr(float64(goods.ZkGoodsPrice) / 100),
		ShopID:     zhios_third_party_utils.IntToStr(goods.MallId),
		ShopName:   goods.MallName,
	}
	img, ok := goods.GoodsGalleryUrls.([]interface{})
	res.Imgs = make([]string, 0)
	if ok {
		for _, v := range img {
			res.Imgs = append(res.Imgs, zhios_third_party_utils.AnyToString(v))
		}
	}
	detailImg, ok := goods.ItemDescUrls.([]interface{})
	res.DetailImgs = make([]string, 0)
	if ok {
		for _, v := range detailImg {
			res.DetailImgs = append(res.DetailImgs, zhios_third_party_utils.AnyToString(v))
		}
	}
	return res
}

func CommKuaishou(eg *xorm.Engine, officialEg *xorm.Engine, dbName string) map[string]string {
	kuaishouAppkey := offical.MasterListCfgGetOneData(officialEg, "0", "kuaishou_appkey")
	kuaishouAppSecret := offical.MasterListCfgGetOneData(officialEg, "0", "kuaishou_app_secret")
	kuaishouSignSecret := offical.MasterListCfgGetOneData(officialEg, "0", "kuaishou_sign_secret")
	kuaishouToken := offical.MasterListCfgGetOneData(officialEg, "0", "kuaishou_token")
	kuaishouPid := offical.MasterListCfgGetOneData(officialEg, "0", "kuaishou_pid")
	puid := AppUserListPuidWithDb(officialEg, dbName)
	puidKuaishouAppkey := offical.MasterListCfgGetOneData(officialEg, puid, "kuaishou_appkey")
	if puidKuaishouAppkey != "" {
		kuaishouAppkey = puidKuaishouAppkey
	}
	puidKuaishouSignSecret := offical.MasterListCfgGetOneData(officialEg, puid, "kuaishou_sign_secret")
	if puidKuaishouSignSecret != "" {
		kuaishouSignSecret = puidKuaishouSignSecret
	}
	puidKuaishouToken := offical.MasterListCfgGetOneData(officialEg, puid, "kuaishou_token")
	if puidKuaishouToken != "" {
		kuaishouToken = puidKuaishouToken
	}
	puidKuaishouPid := offical.MasterListCfgGetOneData(officialEg, puid, "kuaishou_pid")
	if puidKuaishouPid != "" {
		kuaishouPid = puidKuaishouPid
	}
	cfg, _ := db.SysUnionByKuaishouByUseByAuth(eg, dbName)
	authType := ""
	pid := kuaishouPid
	if cfg != nil && cfg.AuthType == 2 { //自有
		authType = zhios_third_party_utils.IntToStr(cfg.AuthType)
		kuaishouToken = gjson.Get(cfg.KeyData, "teamAccessToken").String()
		pid = gjson.Get(cfg.KeyData, "pid").String()
	}
	res := map[string]string{
		"authType":    authType,
		"appkey":      kuaishouAppkey,
		"token":       kuaishouToken,
		"pid":         pid,
		"app_secret":  kuaishouAppSecret,
		"sign_secret": kuaishouSignSecret,
	}
	return res
}

func AppUserListPuidWithDb(officialEg *xorm.Engine, dbName string) string {
	appList := offical.GetUserAppList(officialEg, dbName)
	uid := "0"
	if appList != nil && appList.Puid > 0 {
		uid = zhios_third_party_utils.IntToStr(appList.Puid)
	}
	return uid
}
