package taobao

import (
	"code.fnuoos.com/go_rely_warehouse/zyos_go_third_party_api.git/md"
	zhios_third_party_utils "code.fnuoos.com/go_rely_warehouse/zyos_go_third_party_api.git/utils"
	"encoding/json"
	"fmt"
	"github.com/jinzhu/copier"
)

// 淘宝物料
type Material struct {
	CategoryID           int         `json:"category_id"`
	CategoryName         string      `json:"category_name"`
	CommissionRate       string      `json:"commission_rate"`
	CommissionType       string      `json:"commission_type"`
	CouponID             string      `json:"coupon_id"`
	CouponInfo           string      `json:"coupon_info"`
	CouponRemainCount    int         `json:"coupon_remain_count"`
	CouponTotalCount     int         `json:"coupon_total_count"`
	IncludeDxjh          string      `json:"include_dxjh"`
	IncludeMkt           string      `json:"include_mkt"`
	InfoDxjh             string      `json:"info_dxjh"`
	ItemDescription      string      `json:"item_description"`
	ItemID               interface{} `json:"item_id"`
	ItemURL              string      `json:"item_url"`
	LevelOneCategoryID   int         `json:"level_one_category_id"`
	LevelOneCategoryName string      `json:"level_one_category_name"`
	Nick                 string      `json:"nick"`
	PictURL              string      `json:"pict_url"`
	Provcity             string      `json:"provcity"`
	RealPostFee          string      `json:"real_post_fee"`
	ReservePrice         string      `json:"reserve_price"`
	SellerID             int         `json:"seller_id"`
	ShopDsr              int         `json:"shop_dsr"`
	ShopTitle            string      `json:"shop_title"`
	ShortTitle           string      `json:"short_title"`
	ActivityId           string      `json:"activity_id"`
	SmallImages          struct {
		String []string `json:"string"`
	} `json:"small_images"`
	Title           string      `json:"title"`
	TkTotalCommi    string      `json:"tk_total_commi"`
	TkTotalSales    string      `json:"tk_total_sales"`
	URL             string      `json:"url"`
	UserType        int         `json:"user_type"`
	Volume          int         `json:"volume"`
	WhiteImage      string      `json:"white_image"`
	XID             string      `json:"x_id"`
	ZkFinalPrice    string      `json:"zk_final_price"`
	CouponAmount    string      `json:"coupon_amount,omitempty"`
	OldCouponAmount string      `json:"old_coupon_amount"`
	CouponEndTime   string      `json:"coupon_end_time,omitempty"`
	CouponShareURL  string      `json:"coupon_share_url,omitempty"`
	CouponStartFee  string      `json:"coupon_start_fee,omitempty"`
	CouponStartTime string      `json:"coupon_start_time,omitempty"`
	InputNumIid     interface{} `json:"input_num_iid"`
}

type wrapperStruct struct {
	TbkDgMaterialOptionalResponse struct {
		ResultList struct {
			MapData []Material `json:"map_data"`
		} `json:"result_list"`
	} `json:"tbk_dg_material_optional_response"`
}
type tbDetailStruct struct {
	TbkItemInfoGetResponse struct {
		Results struct {
			NBbkItem []Material `json:"n_tbk_item"`
		} `json:"results"`
	} `json:"tbk_item_info_get_response"`
}
type scMaterialOptionalStruct struct {
	TbkScMaterialOptionalResponse struct {
		ResultList struct {
			MapData []Material `json:"map_data"`
		} `json:"result_list"`
	} `json:"tbk_sc_material_optional_response"`
}

type featuredWrapperStruct struct {
	TbkDgMaterialOptionalResponse struct {
		ResultList struct {
			MapData []md.TBSearchFeatureStruct `json:"map_data"`
		} `json:"result_list"`
	} `json:"tbk_dg_material_optional_response"`
}
type featuredScMaterialOptionalStruct struct {
	TbkScMaterialOptionalResponse struct {
		ResultList struct {
			MapData []md.TBSearchFeatureStruct `json:"map_data"`
		} `json:"result_list"`
	} `json:"tbk_sc_material_optional_response"`
}

var sortList = map[string]struct{}{
	"total_sales_asc":    {}, //销量从低到高
	"total_sales_des":    {}, //销量从高到低
	"price_asc":          {}, //价格从低到高
	"price_des":          {}, //价格从高到低
	"tk_rate_des":        {}, //佣金比率从高到低
	"tk_rate_asc":        {}, //佣金比率从低到高
	"tk_total_sales_asc": {}, //累计推广量从低到高
	"tk_total_sales_des": {}, //累计推广量成高到低
	"tk_total_commi_asc": {}, //总支出佣金从低到高
	"tk_total_commi_des": {}, //总支出佣金高到低
}

func (t *TB) GetList(tbArgs map[string]string, bizSceneId string) ([]byte, error) {
	args := map[string]string{
		"q":         tbArgs["keyword"],
		"adzone_id": AdZoneId(t.SelfPromoIdWeb),
		"page_size": zhios_third_party_utils.IntToStr(zhios_third_party_utils.StrToInt(tbArgs["pageSize"])),
		"page_no":   zhios_third_party_utils.IntToStr(zhios_third_party_utils.StrToInt(tbArgs["pageIndex"])),
		"platform":  "2",            // 链接形式-1：PC,2：无线,默认为１
		"sort":      tbArgs["sort"], // 排序_des(降序),排序_asc(升序),销量(total_sales)淘客佣金比率(tk_rate)累计推广量(tk_total_sales),总支出佣金(tk_total_commi),价格(price)

		//"site_id" : "",
	}
	if bizSceneId != "" {
		args["biz_scene_id"] = "2"
	}
	method := TBK_DG_MTL_OPT
	//判断是否跟随官方 需要换接口
	if t.AuthType == 1 {
		method = TBK_SC_MTL_OPT
		Sid := t.UserSID
		args["session"] = Sid
		_, args["site_id"], args["adzone_id"] = SplitPid(t.SelfPromoIdWeb)
	}
	// TODO:  args[sort] 修复为 args["sort"]
	if _, ok := args["sort"]; !ok {
		// TODO 按销量高到低排序 而不是 推广量高到低排序
		// args["sort"] = "tk_total_sales_des"
		// TODO 现修改为：按销量高到低排序
		args["sort"] = "total_sales_des"
	}
	if args["sort"] == "" {
		args["sort"] = "total_sales_des"
	}
	if zhios_third_party_utils.StrToFloat64(tbArgs["startPrice"]) > 0 {
		// TODO 数据库中存储的类型为decimal(11,2)（decimal表现形式类似浮点型，但底层结构不一样），无法正常将数据库中的decimal字符串转换int
		// args["start_price"] = utils.IntToStr(utils.StrToInt(startPrice))
		// TODO 修复为：
		args["start_price"] = fmt.Sprintf("%.0f", zhios_third_party_utils.StrToFloat64(tbArgs["startPrice"])) //utils.IntToStr(utils.StrToInt(startPrice))
	}
	if zhios_third_party_utils.StrToFloat64(tbArgs["startCommissionRate"]) > 0 {
		args["start_tk_rate"] = tbArgs["startCommissionRate"]
	}
	if zhios_third_party_utils.StrToFloat64(tbArgs["endCommissionRate"]) > 0 {
		args["end_tk_rate"] = tbArgs["endCommissionRate"]
	}
	if zhios_third_party_utils.StrToFloat64(tbArgs["endPrice"]) > 0 {
		args["end_price"] = zhios_third_party_utils.IntToStr(zhios_third_party_utils.StrToInt(tbArgs["endPrice"]))
	}
	if tbArgs["isTmall"] == "true" {
		args["is_tmall"] = "true"
	}
	if tbArgs["isCoupon"] == "true" {
		args["has_coupon"] = tbArgs["isCoupon"]
	}
	resp, err := send(args, method, t.Web_AK, t.Web_SK)
	if err != nil {
		return []byte(""), err
	}
	return resp, nil
}
func (t *TB) SearchList(args map[string]string) (*[]Material, error) {
	resp, err := t.GetList(args, "")
	//如果是跟随官方 结构不一样
	if t.AuthType == 1 {
		var tmp scMaterialOptionalStruct
		if err = json.Unmarshal(resp, &tmp); err != nil {
			return nil, err
		}
		if len(tmp.TbkScMaterialOptionalResponse.ResultList.MapData) == 0 {
			return nil, err
		}
		data := tmp.TbkScMaterialOptionalResponse.ResultList.MapData
		for k, v := range data {
			itemID, ok := v.ItemID.(float64)
			if ok {
				data[k].ItemID = int64(itemID)
			}
		}
		return &data, nil
	} else {
		var tmp wrapperStruct
		if err = json.Unmarshal(resp, &tmp); err != nil {
			return nil, err
		}
		if len(tmp.TbkDgMaterialOptionalResponse.ResultList.MapData) == 0 {
			return nil, err
		}
		data := tmp.TbkDgMaterialOptionalResponse.ResultList.MapData
		for k, v := range data {
			itemID, ok := v.ItemID.(float64)
			if ok {
				data[k].ItemID = int64(itemID)
			}
		}
		return &data, nil
	}

}

func (t *TB) FeaturedList(args map[string]string) (*[]md.TBFeatureStruct, error) {
	resp, err := t.GetList(args, "")
	//如果是跟随官方 结构不一样
	if t.AuthType == 1 {
		var tmp featuredScMaterialOptionalStruct
		if err = json.Unmarshal(resp, &tmp); err != nil {
			return nil, err
		}
		if len(tmp.TbkScMaterialOptionalResponse.ResultList.MapData) == 0 {
			return nil, err
		}
		var data = tmp.TbkScMaterialOptionalResponse.ResultList.MapData
		var res []md.TBFeatureStruct
		for _, v := range data {
			var tmp md.TBFeatureStruct
			copier.Copy(&tmp, v)
			tmp.ItemID = zhios_third_party_utils.AnyToString(v.ItemID)
			tmp.CouponAmount = zhios_third_party_utils.StrToInt(v.CouponAmount)
			res = append(res, tmp)
		}
		return &res, nil
	} else {
		var tmp featuredWrapperStruct
		if err = json.Unmarshal(resp, &tmp); err != nil {
			return nil, err
		}
		if len(tmp.TbkDgMaterialOptionalResponse.ResultList.MapData) == 0 {
			return nil, err
		}
		var data = tmp.TbkDgMaterialOptionalResponse.ResultList.MapData
		var res []md.TBFeatureStruct
		for _, v := range data {
			var tmp md.TBFeatureStruct
			copier.Copy(&tmp, v)
			tmp.ItemID = zhios_third_party_utils.AnyToString(v.ItemID)
			tmp.CouponAmount = zhios_third_party_utils.StrToInt(v.CouponAmount)
			res = append(res, tmp)
		}
		return &res, nil
	}

}
